
import QtQuick 2.2
import QtQml 2.2
import QtQuick.Controls 1.1

import FmShareFile 1.0
/*!
    \qmltype AppShareFile
    \since FmShareFile 1.0
    \inqmlmodule FmShareFile
    \brief 系统内分享文件组件

    此组件是单例组件，可定义多个在多个地方使用，但收到的信号和内容都是一样的;
    若是本应用收到其他应用发来的文件时，本组件还未初始化完成，可用 getReceiveFiles() 获取收到的文件的路径。

    用法示例：
    \code
    AppShareFile{
        id:idFmShareFile
        onReceiveFiles：｛
        ｝
    }
    \endcode

    Android需要配置如下：
     \list
        \li 修改启动方式(在需要AndroidManifest.xml中接收Intent的 activity 配置中设置)
            在<activity>标签下：
            \code
                android:launchMode="singleTask"

            \endcode

            \li 添加Intent筛选器 android:mimeType可设置具体的文件过滤类型，如：text/plain, text/*(代表筛选所有text类型文件),*\/*(代表筛选所有文件)
                在<activity>标签下：

                \code
                <intent-filter>
                    <action android:name="android.intent.action.VIEW"></action>
                    <category android:name="android.intent.category.DEFAULT"></category>
                    <data android:mimeType="*\/*"></data>
                </intent-filter>

                <intent-filter>
                    <action android:name="android.intent.action.SEND" />
                    <category android:name="android.intent.category.DEFAULT" />
                    <data android:mimeType="*\/*" />
                </intent-filter>
                \endcode
     \endlist

     Android 先 MainActivity.java需要修改如下：
     \list
        \li import 程序包

            \code
                import android.net.Uri;
                import java.lang.reflect.Method;
                import android.app.Activity;
                import android.content.Intent;
                import android.os.Bundle;
                import android.app.PendingIntent;

            \endcode

            \li 添加处理收到的Intent的函数

                \code
                    public void dealIntent(Intent intent){
                        Bundle extras = intent.getExtras();
                        String action = intent.getAction();
                        String type = intent.getType();
                        String sch  = intent.getScheme();
                        String uriStr  = intent.getDataString();
                        if (extras !== null){
                            if(extras.containsKey(Intent.EXTRA_STREAM))
                                uriStr = ((Uri) extras.getParcelable(Intent.EXTRA_STREAM)).getPath();
                        }

                        if(uriStr !== null){
                            Uri uriPath = Uri.parse(uriStr);
                            String path = uriPath.getPath();

                            try{
                                Class c = Class.forName("fm.fmsharefile.module");
                                if(c !== null){
                                    Method method= c.getMethod("init",Activity.class,String.class);
                                        if(method !== null)
                                                method.invoke(c,this,path);
                                }
                            }catch(Exception e){
                                System.out.println("OpenFileActivity Exception:::"+e);
                            }
                        }
                    }
                \endcode

                \li 在 public void onCreate(Bundle savedInstanceState) 函数中添加处理收到的Intent的函数 的调用
                    \code
                        Intent intent = getIntent();
                        if(intent !== null)
                              dealIntent(intent);
                    \endcode
                \li 在 public void onNewIntent(Intent intent) 函数中添加处理收到的Intent的函数 的调用
                    \code
                        if(intent !== null)
                              dealIntent(intent);
                    \endcode
     \endlist


     ios需要配置如下：
     \list
        \li 修改配置文件info.plist
            可根据需要添加要筛选的文件类型LSItemContentTypes
            \code
                <key>CFBundleDocumentTypes</key>
                    <array>
                        <dict>
                            <key>CFBundleTypeName</key>
                            <string>com.myapp.common-data</string>
                            <key>LSHandlerRank</key>
                            <string>Owner</string>
                            <key>LSItemContentTypes</key>
                            <array>
                                <string>com.microsoft.powerpoint.ppt</string>
                                <string>public.item</string>
                                <string>com.microsoft.word.doc</string>
                                <string>com.adobe.pdf</string>
                                <string>com.microsoft.excel.xls</string>
                                <string>public.image</string>
                                <string>public.content</string>
                                <string>public.composite-content</string>
                                <string>public.archive</string>
                                <string>public.audio</string>
                                <string>public.movie</string>
                                <string>public.text</string>
                                <string>public.data</string>
                            </array>
                        </dict>
                    </array>

            \endcode

        \li 修改qiosapplicationdelegate.mm 文件
            \list
                \li 在QIOSApplicationDelegate类中定义属性 openfile
                    \code
                        id openfile;
                    \endcode
                \li 在重写的- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions方法中添加如下：
                    \code
                        Class OpenFileInit = NSClassFromString(@"FmOpenFileInit");
                        if(OpenFileInit)
                            if ([OpenFileInit respondsToSelector:@selector(init)]) {
                                openfile = [[OpenFileInit alloc] init];
                        }
                    \endcode
                 \li 重写 - (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(NSString *)sourceApplication annotation:(id)annotation 代理方法
                    \code
                        - (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(NSString *)sourceApplication annotation:(id)annotation
                        {
                            if (url != nil) {
                                NSString *path = [url absoluteString];
                                NSMutableString *string = [[NSMutableString alloc] initWithString:path];
                                if ([path hasPrefix:@"file://"]) {
                                    [string replaceOccurrencesOfString:@"file://" withString:@"" options:NSCaseInsensitiveSearch  range:NSMakeRange(0, path.length)];
                                }

                                Class OpenFileInit = NSClassFromString(@"FmOpenFileInit");

                                if (openfile) {
                                    [openfile receiveFiles:string];
                                }else{
                                    if ([OpenFileInit respondsToSelector:@selector(init)]) {
                                        openfile = [[OpenFileInit alloc] init];
                                        [openfile receiveFiles:string];
                                    }
                                }
                            }
                            return YES;
                        }

                    \endcode
            \endlist
     \endlist
*/
Item{
    id:idItem
    //单例模式，不能使用如下方式
//    FmShareFile{
//        id:_shareFile

//        onReceiveFiles:{
//            receiveFiles(files);
//        }
//    }


    property var getReceiveFiles: function(){
        var str = ShareFile.getReceiveFiles();
        return str;
    }

    property var resetReceiveFiles: function(){
          ShareFile.resetReceiveFiles();
    }

    property var getReceiveLinkUrl: function(){
        var str = ShareFile.getReceiveLinkUrl();
        return dealLinkText(str);
    }

    property var resetReceiveLinkUrl: function(){
          ShareFile.resetReceiveLinkUrl();
    }

    signal receiveFiles(var files);

    signal reviceLinkUrl(var linkUrl);

    function dealLinkText(linkText){
        if(!linkText)
            return "";
        if(linkText.length == 0)
            return "";
        linkText = linkText.replace("https://","http://");
        var reg = /http:\/\/([\w-]+\.)+[\w-]+(\/[\w- ./?%&=#!]*)?/
        var arrUrl = linkText.match(reg);
        if(arrUrl){
            var urlTem = arrUrl[0];
            return urlTem;
        }
        return "";
    }

    Connections{
        target:ShareFile
        onFilesChanged:{
            idItem.receiveFiles(files);
        }
        onLinkUrlChanged:{
            idItem.reviceLinkUrl(dealLinkText(linkUrl));
        }
    }
}
